#ifndef MODULEFACTORY_H
#define MODULEFACTORY_H

#include <qworkspace.h>
#include "MainWin.h"

#ifdef HAVE_QSA_FAC
class QSInterpreter;
#include <qsobjectfactory.h>

class ModuleFactory : public QSObjectFactory
#else
class ModuleFactory
#endif
{

public:
    ModuleFactory(MainWin *mw, QWorkspace *ws);

#ifdef HAVE_QSA_FAC
    virtual QObject *create( const QString &type,
    	const QSArgumentList &args,QObject *context );
#endif
private:
	MainWin *mw;
	QWorkspace *ws;
};

#endif //MODULEFACTORY_H
